import CircularProgress from '@mui/material/CircularProgress'
import { useUser } from '@/utils/useUser'
import Alert from '@mui/material/Alert'
import Button from '@mui/material/Button'
import { useRouter } from 'next/router'
import { DeleteUser } from './components/DeleteUser'
import * as api from '@/api'

export default function Home() {
  const { user, isLoading, errMsg } = useUser()
  const router = useRouter()

  if (isLoading) {
    return (
      <CircularProgress
        sx={{
          position: 'fixed',
          top: '30%',
          left: '50%',
          transform: 'translate(-50%, -50%)',
        }}
      />
    )
  }

  if (errMsg) {
    return <Alert severity="error">{errMsg}</Alert>
  }

  async function logout() {
    await api.user.logout()
    localStorage.removeItem('accessToken')
    router.push('/login')
  }

  return (
    <>
      <Alert severity="success">hello {user!.email}</Alert>
      <Button onClick={logout}>退出登录</Button>
      <DeleteUser />
    </>
  )
}
